#ifndef __MTM_VIEW_EXTENSIONS_H__
#define __MTM_VIEW_EXTENSIONS_H__

GtkWidget * mtm_view_extensions_new (MtmSelector *selector);

#endif /* __MTM_VIEW_EXTENSIONS_H__ */
